@@ -5,7 +5,7 @@ use App::cpm::version;
 use App::cpm::DistNotation;
 use Cwd ();
 use File::Path ();
-our $VERSION = '0.971';
+our $VERSION = '0.972';
 
 {
     package
@@ -39,7 +39,7 @@ our $VERSION = '0.971';
         } else {
             $path =~ s{^file://}{};
             die "$path: No such file.\n" unless -f $path;
-            if (!-f $dest or (stat $dest)[9] < (stat $path)[9]) {
+            if (!-f $dest or (stat $dest)[9] <= (stat $path)[9]) {
                 File::Copy::copy($path, $dest) or die "Copy $path $dest: $!\n";
                 my $mtime = (stat $path)[9];
                 utime $mtime, $mtime, $dest;
@@ -49,7 +49,7 @@ our $VERSION = '0.971';
         if ($dest =~ /\.gz$/) {
             ( my $uncompressed = File::Basename::basename($dest) ) =~ s/\.gz$//;
             $uncompressed = File::Spec->catfile( $self->cache, $uncompressed );
-            if ( !-f $uncompressed or (stat $uncompressed)[9] < (stat $dest)[9] ) {
+            if ( !-f $uncompressed or (stat $uncompressed)[9] <= (stat $dest)[9] ) {
                 no warnings 'once';
                 IO::Uncompress::Gunzip::gunzip($dest, $uncompressed)
                     or die "Gunzip $dest: $IO::Uncompress::Gunzip::GunzipError";
